@@ -3,16 +3,16 @@
 # Copyright 2004-2009 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
-# modify it under the terms of the GNU Library General Public
+# modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Library General Public
+# You should have received a copy of the GNU Lesser General Public
 # License along with this library; if not, write to the
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
@@ -392,6 +392,9 @@ formatting = {
             'unfocused': '[Component(obj,\
                                      asString(((label + displayedText) or name) + value + roleName + alertAndDialogCount))]'
             },
+        pyatspi.ROLE_HEADING: {
+            'unfocused': '[Text(obj)] + [Region(" " + asString(roleName))]'
+            },
         #pyatspi.ROLE_HTML_CONTAINER: 'default'
         pyatspi.ROLE_ICON: {
             'unfocused': '[Component(obj,\
@@ -403,6 +406,11 @@ formatting = {
                                 asString(label),\
                                 asString(eol))]'
             },
+        pyatspi.ROLE_LINK: {
+            'unfocused': '[Link(obj, asString(currentLineText)\
+                                     or asString(displayedText)\
+                                     or asString(name))]',
+        },
         #pyatspi.ROLE_LIST: 'default'
         pyatspi.ROLE_LIST_ITEM: {
             'focused':   '[Component(obj,\
