@@ -30,9 +30,8 @@ import pyatspi
 
 import orca.orca as orca
 import orca.debug as debug
-import orca.default as default
+import orca.scripts.default as default
 import orca.orca_state as orca_state
-import orca.settings as settings
 import orca.speech as speech
 import orca.scripts.toolkits.Gecko as Gecko
 
@@ -43,6 +42,8 @@ from speech_generator import SpeechGenerator
 from script_utilities import Utilities
 import script_settings
 
+_settingsManager = getattr(orca, '_settingsManager')
+
 ########################################################################
 #                                                                      #
 # The Thunderbird script class.                                        #
@@ -213,8 +214,7 @@ class Script(Gecko.Script):
                 event.source.getState().contains(pyatspi.STATE_EDITABLE)
 
         if updatePosition:
-            orca.setLocusOfFocus(
-                event, event.source, notifyPresentationManager=False)
+            orca.setLocusOfFocus(event, event.source, notifyScript=False)
             self.setCaretContext(event.source, event.detail1)
 
             # The Gecko script, should it be about to pass along this
@@ -338,6 +338,7 @@ class Script(Gecko.Script):
         # Handle a newly-opened message.
         #
         if event.source.getRole() == pyatspi.ROLE_DOCUMENT_FRAME \
+           and orca_state.locusOfFocus \
            and orca_state.locusOfFocus.getRole() == pyatspi.ROLE_FRAME:
             if self._messageLoaded:
                 consume = True
@@ -616,7 +617,7 @@ class Script(Gecko.Script):
         self.setCaretPosition(obj, offset)
         if not script_settings.sayAllOnLoad:
             self.presentLine(obj, offset)
-        elif settings.enableSpeech:
+        elif _settingsManager.getSetting('enableSpeech'):
             self.sayAll(None)
         self._messageLoaded = False
 
